@@ -29,11 +29,9 @@
 # 05-SEP-2019   B. Ulmann   Added set_ro_group and read_ro_group functions.
 # 11-SEP-2019   B. Ulmann   Made HyCon into a proper Perl module suitable 
 #                           for CPAN.
-# 12-SEP-2019   B. Ulmann   Added requirements to Makefile.PL which were 
-#                           missing.
 #
 
-package IO::HyCon;
+package HyCon;
 
 =pod
 
@@ -43,7 +41,7 @@ IO::HyCon - Perl interface to the Analog Paradigm hybrid controller.
 
 =head1 VERSION
 
-This document refers to version 0.1 of HyCon
+This document refers to version 0.5 of HyCon
 
 =head1 SYNOPSIS
 
@@ -77,7 +75,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-our $VERSION = '0.1_2';
+our $VERSION = '0.5';
 
 use YAML qw(LoadFile);
 use Carp qw(confess cluck carp);
